@@ -17,7 +17,7 @@
 #define U_DISABLE_JANSSON
 #define U_DISABLE_CURL
 #define U_DISABLE_WEBSOCKET
-#include "../../include/ulfius.h"
+#include <ulfius.h>
 
 #define PORT 2884
 #define PREFIX "/auth"
@@ -68,7 +68,7 @@ int main (int argc, char **argv) {
   
   // Start the framework
   if (ulfius_start_framework(&instance) == U_OK) {
-    printf("Start framework on port %d\n", instance.port);
+    printf("Start framework on port %u\n", instance.port);
     
     // Wait for the user to press <enter> on the console to quit the application
     printf("Press <enter> to quit server\n");
