@@ -15,7 +15,7 @@
 #include <jansson.h>
 
 #define U_DISABLE_WEBSOCKET
-#include "../../include/ulfius.h"
+#include <ulfius.h>
 
 #define SERVER_URL_PREFIX "http://localhost:7778/curl"
 
@@ -33,10 +33,10 @@ char * print_map(const struct _u_map * map) {
       line = o_malloc((len+1)*sizeof(char));
       snprintf(line, (len+1), "key is %s, value is %s\n", keys[i], u_map_get(map, keys[i]));
       if (to_return != NULL) {
-        len = strlen(to_return) + strlen(line) + 1;
+        len = o_strlen(to_return) + o_strlen(line) + 1;
         to_return = o_realloc(to_return, (len+1)*sizeof(char));
       } else {
-        to_return = o_malloc((strlen(line) + 1)*sizeof(char));
+        to_return = o_malloc((o_strlen(line) + 1)*sizeof(char));
         to_return[0] = 0;
       }
       strcat(to_return, line);
@@ -52,7 +52,7 @@ void print_response(struct _u_response * response) {
   if (response != NULL) {
     char * headers = print_map(response->map_header);
     char response_body[response->binary_body_length + 1];
-    strncpy(response_body, response->binary_body, response->binary_body_length);
+    o_strncpy(response_body, response->binary_body, response->binary_body_length);
     response_body[response->binary_body_length] = '\0';
     printf("protocol is\n%s\n\n  headers are \n%s\n\n  body is \n%s\n\n",
            response->protocol, headers, response_body);
@@ -96,57 +96,57 @@ int main (int argc, char **argv) {
   ulfius_init_request(&req_list[7]);
   
   // Parameters in url
-  req_list[0].http_verb = strdup("GET");
-  req_list[0].http_url = strdup(SERVER_URL_PREFIX "/get/");
+  req_list[0].http_verb = o_strdup("GET");
+  req_list[0].http_url = o_strdup(SERVER_URL_PREFIX "/get/");
   req_list[0].timeout = 20;
   u_map_copy_into(req_list[0].map_url, &url_params);
   
   // No parameters
-  req_list[1].http_verb = strdup("DELETE");
-  req_list[1].http_url = strdup(SERVER_URL_PREFIX "/delete/");
+  req_list[1].http_verb = o_strdup("DELETE");
+  req_list[1].http_url = o_strdup(SERVER_URL_PREFIX "/delete/");
   req_list[1].timeout = 20;
   
   // Parameters in post_map and string_body
-  req_list[2].http_verb = strdup("POST");
-  req_list[2].http_url = strdup(SERVER_URL_PREFIX "/post/param/");
+  req_list[2].http_verb = o_strdup("POST");
+  req_list[2].http_url = o_strdup(SERVER_URL_PREFIX "/post/param/");
   req_list[2].timeout = 20;
   u_map_copy_into(req_list[2].map_post_body, &post_params);
-  req_list[2].binary_body = strdup(string_body);
-  req_list[2].binary_body_length = strlen(string_body);
+  req_list[2].binary_body = o_strdup(string_body);
+  req_list[2].binary_body_length = o_strlen(string_body);
   
   // Paremeters in string body, header MHD_HTTP_POST_ENCODING_FORM_URLENCODED
-  req_list[3].http_verb = strdup("POST");
-  req_list[3].http_url = strdup(SERVER_URL_PREFIX "/post/plain/");
+  req_list[3].http_verb = o_strdup("POST");
+  req_list[3].http_url = o_strdup(SERVER_URL_PREFIX "/post/plain/");
   req_list[3].timeout = 20;
   u_map_copy_into(req_list[3].map_header, &req_headers);
-  req_list[3].binary_body = strdup(string_body);
-  req_list[3].binary_body_length = strlen(string_body);
+  req_list[3].binary_body = o_strdup(string_body);
+  req_list[3].binary_body_length = o_strlen(string_body);
   
   // Parameters in json_body
-  req_list[4].http_verb = strdup("POST");
-  req_list[4].http_url = strdup(SERVER_URL_PREFIX "/post/json/");
+  req_list[4].http_verb = o_strdup("POST");
+  req_list[4].http_url = o_strdup(SERVER_URL_PREFIX "/post/json/");
   req_list[4].timeout = 20;
   u_map_copy_into(req_list[4].map_url, &url_params);
   ulfius_set_json_body_request(&req_list[4], json_body);
   
   // Paremeters in string body, header MHD_HTTP_POST_ENCODING_FORM_URLENCODED
-  req_list[5].http_verb = strdup("PUT");
-  req_list[5].http_url = strdup(SERVER_URL_PREFIX "/put/plain/");
+  req_list[5].http_verb = o_strdup("PUT");
+  req_list[5].http_url = o_strdup(SERVER_URL_PREFIX "/put/plain/");
   req_list[5].timeout = 20;
   u_map_copy_into(req_list[5].map_header, &req_headers);
-  req_list[5].binary_body = strdup(string_body);
-  req_list[5].binary_body_length = strlen(string_body);
+  req_list[5].binary_body = o_strdup(string_body);
+  req_list[5].binary_body_length = o_strlen(string_body);
   
   // Parameters in json_body
-  req_list[6].http_verb = strdup("PUT");
-  req_list[6].http_url = strdup(SERVER_URL_PREFIX "/put/json/");
+  req_list[6].http_verb = o_strdup("PUT");
+  req_list[6].http_url = o_strdup(SERVER_URL_PREFIX "/put/json/");
   req_list[6].timeout = 20;
   u_map_copy_into(req_list[6].map_url, &url_params);
   ulfius_set_json_body_request(&req_list[6], json_body);
   
   // Parameters in post_map
-  req_list[7].http_verb = strdup("POST");
-  req_list[7].http_url = strdup(SERVER_URL_PREFIX "/post/param/");
+  req_list[7].http_verb = o_strdup("POST");
+  req_list[7].http_url = o_strdup(SERVER_URL_PREFIX "/post/param/");
   req_list[7].timeout = 20;
   u_map_copy_into(req_list[6].map_post_body, &post_params);
   
