@@ -21,7 +21,7 @@
 
 #define U_DISABLE_CURL
 #define U_DISABLE_WEBSOCKET
-#include "../../include/ulfius.h"
+#include <ulfius.h>
 
 #define PORT 8537
 #define PREFIX "/test"
@@ -58,13 +58,13 @@ char * print_map(const struct _u_map * map) {
       line = o_malloc((len+1)*sizeof(char));
       snprintf(line, (len+1), "key is %s, value is %s", keys[i], value);
       if (to_return != NULL) {
-        len = strlen(to_return) + strlen(line) + 1;
+        len = o_strlen(to_return) + o_strlen(line) + 1;
         to_return = o_realloc(to_return, (len+1)*sizeof(char));
-        if (strlen(to_return) > 0) {
+        if (o_strlen(to_return) > 0) {
           strcat(to_return, "\n");
         }
       } else {
-        to_return = o_malloc((strlen(line) + 1)*sizeof(char));
+        to_return = o_malloc((o_strlen(line) + 1)*sizeof(char));
         to_return[0] = 0;
       }
       strcat(to_return, line);
@@ -80,23 +80,18 @@ char * read_file(const char * filename) {
   char * buffer = NULL;
   long length;
   FILE * f = fopen (filename, "rb");
-  if (filename != NULL) {
-
-    if (f) {
-      fseek (f, 0, SEEK_END);
-      length = ftell (f);
-      fseek (f, 0, SEEK_SET);
-      buffer = o_malloc (length + 1);
-      if (buffer) {
-        fread (buffer, 1, length, f);
-      }
+  if (f != NULL) {
+    fseek (f, 0, SEEK_END);
+    length = ftell (f);
+    fseek (f, 0, SEEK_SET);
+    buffer = o_malloc (length + 1);
+    if (buffer != NULL) {
+      fread (buffer, 1, length, f);
       buffer[length] = '\0';
-      fclose (f);
     }
-    return buffer;
-  } else {
-    return NULL;
+    fclose (f);
   }
+  return buffer;
 }
 
 int main (int argc, char **argv) {
@@ -132,7 +127,7 @@ int main (int argc, char **argv) {
   ulfius_set_default_endpoint(&instance, &callback_default, NULL);
   
   // Start the framework
-  if (argc == 4 && strcmp("-secure", argv[1]) == 0) {
+  if (argc == 4 && o_strcmp("-secure", argv[1]) == 0) {
     // If command-line options are -secure <key_file> <cert_file>, then open an https connection
     char * key_pem = read_file(argv[2]), * cert_pem = read_file(argv[3]);
     ret = ulfius_start_secure_framework(&instance, key_pem, cert_pem);
@@ -144,7 +139,7 @@ int main (int argc, char **argv) {
   }
   
   if (ret == U_OK) {
-    y_log_message(Y_LOG_LEVEL_DEBUG, "Start %sframework on port %d", ((argc == 4 && strcmp("-secure", argv[1]) == 0)?"secure ":""), instance.port);
+    y_log_message(Y_LOG_LEVEL_DEBUG, "Start %sframework on port %d", ((argc == 4 && o_strcmp("-secure", argv[1]) == 0)?"secure ":""), instance.port);
     
     // Wait for the user to press <enter> on the console to quit the application
     getchar();
