@@ -45,14 +45,14 @@ START_TEST(test_u_map_get)
   ck_assert_int_eq(u_map_put(&map, "key", "value"), U_OK);
   ck_assert_str_eq(u_map_get(&map, "key"), "value");
   ck_assert_int_eq(u_map_get_length(&map, "key"), 6);
-  ck_assert_ptr_eq(u_map_get(&map, "nope"), NULL);
-  ck_assert_ptr_eq(u_map_get(NULL, "key"), NULL);
+  ck_assert_ptr_eq((void *)u_map_get(&map, "nope"), NULL);
+  ck_assert_ptr_eq((void *)u_map_get(NULL, "key"), NULL);
   ck_assert_int_eq(u_map_get_length(&map, "nope"), -1);
   ck_assert_int_eq(u_map_get_length(NULL, "key"), -1);
   ck_assert_str_eq(u_map_get_case(&map, "Key"), "value");
   ck_assert_int_eq(u_map_get_case_length(&map, "kEy"), 6);
-  ck_assert_ptr_eq(u_map_get_case(&map, "noPE"), NULL);
-  ck_assert_ptr_eq(u_map_get_case(NULL, "keY"), NULL);
+  ck_assert_ptr_eq((void *)u_map_get_case(&map, "noPE"), NULL);
+  ck_assert_ptr_eq((void *)u_map_get_case(NULL, "keY"), NULL);
   ck_assert_int_eq(u_map_get_case_length(&map, "noPe"), -1);
   ck_assert_int_eq(u_map_get_case_length(NULL, "KEy"), -1);
   u_map_clean(&map);
@@ -66,8 +66,8 @@ START_TEST(test_u_map_get_case)
   ck_assert_int_eq(u_map_put(&map, "key", "value"), U_OK);
   ck_assert_str_eq(u_map_get(&map, "key"), "value");
   ck_assert_int_eq(u_map_get_case_length(&map, "key"), 6);
-  ck_assert_ptr_eq(u_map_get_case(&map, "nope"), NULL);
-  ck_assert_ptr_eq(u_map_get_case(NULL, "key"), NULL);
+  ck_assert_ptr_eq((void *)u_map_get_case(&map, "nope"), NULL);
+  ck_assert_ptr_eq((void *)u_map_get_case(NULL, "key"), NULL);
   ck_assert_int_eq(u_map_get_case_length(&map, "nope"), -1);
   ck_assert_int_eq(u_map_get_case_length(NULL, "key"), -1);
   u_map_clean(&map);
